==> jc-1.4.0.tar.gz: javax/print/attribute/standard/MediaSizeName.h <==
// public class javax.print.attribute.standard.MediaSizeName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class ab3220e6946f401b javax_print_attribute_standard_Media
// @dep_class b153305f4aacd945 javax_print_attribute_standard_MediaSizeName

// header file dependencies
// @dep_header javax_print_attribute_standard_Media

#include "javax/print/attribute/standard/Media.h"

#ifndef _JC_javax_print_attribute_standard_MediaSizeName_H_
#define _JC_javax_print_attribute_standard_MediaSizeName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_standard_MediaSizeName$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_MediaSizeName$sub_refs	_jc_javax_print_attribute_standard_MediaSizeName$sub_refs;
typedef struct _jc_javax_print_attribute_standard_MediaSizeName$sub_nonrefs	_jc_javax_print_attribute_standard_MediaSizeName$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_MediaSizeName$refs	_jc_javax_print_attribute_standard_MediaSizeName$refs;
typedef struct _jc_javax_print_attribute_standard_MediaSizeName$nonrefs	_jc_javax_print_attribute_standard_MediaSizeName$nonrefs;
typedef struct _jc_javax_print_attribute_standard_MediaSizeName$object	_jc_javax_print_attribute_standard_MediaSizeName$object;

typedef struct _jc_javax_print_attribute_standard_MediaSizeName$fields_struct	_jc_javax_print_attribute_standard_MediaSizeName$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_MediaSizeName$vmethods	_jc_javax_print_attribute_standard_MediaSizeName$vmethods;
typedef const struct _jc_javax_print_attribute_standard_MediaSizeName$vtable	_jc_javax_print_attribute_standard_MediaSizeName$vtable;
typedef const struct _jc_javax_print_attribute_standard_MediaSizeName$vtype	_jc_javax_print_attribute_standard_MediaSizeName$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_MediaSizeName$fields_struct {
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*A;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*B;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*C;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*D;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*E;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*EXECUTIVE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*FOLIO;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*INVOICE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA0;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA1;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA10;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA2;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA3;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA4;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA5;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA6;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA7;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA8;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA9;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB0;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB1;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB10;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB2;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB3;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB4;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB5;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB6;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB7;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB8;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB9;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fC0;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fC1;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fC2;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fC3;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fC4;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fC5;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fC6;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fDESIGNATED__5fLONG;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ITALY__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JAPANESE__5fDOUBLE__5fPOSTCARD;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JAPANESE__5fPOSTCARD;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB0;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB1;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB10;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB2;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB3;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB4;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB5;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB6;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB7;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB8;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB9;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*LEDGER;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*MONARCH__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f10X13__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f10X14__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f10X15__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f5X7;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f6X9__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f7X9__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f8X10;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f9X11__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f9X12__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5fLEGAL;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5fLETTER;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5fNUMBER__5f10__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5fNUMBER__5f11__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5fNUMBER__5f12__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5fNUMBER__5f14__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5fNUMBER__5f9__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*PERSONAL__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*QUARTO;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*TABLOID;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_MediaSizeName$fields_struct _jc_javax_print_attribute_standard_MediaSizeName$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_MediaSizeName$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSizeName$object *, jint);

// Static methods
extern void _jc_javax_print_attribute_standard_MediaSizeName$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_MediaSizeName$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_standard_MediaSizeName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_Media$vmethods	javax_print_attribute_standard_Media;
	_jc_javax_print_attribute_standard_MediaSizeName$vmethods	javax_print_attribute_standard_MediaSizeName;
};

// Vtype
struct _jc_javax_print_attribute_standard_MediaSizeName$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_MediaSizeName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_MediaSizeName$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_MediaSizeName$refs {
    _jc_javax_print_attribute_standard_MediaSizeName$sub_refs	javax_print_attribute_standard_MediaSizeName;
    _jc_javax_print_attribute_standard_Media$sub_refs	javax_print_attribute_standard_Media;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_MediaSizeName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_MediaSizeName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_Media$sub_nonrefs	javax_print_attribute_standard_Media;
    _jc_javax_print_attribute_standard_MediaSizeName$sub_nonrefs	javax_print_attribute_standard_MediaSizeName;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_MediaSizeName$object {
	_jc_javax_print_attribute_standard_MediaSizeName$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_MediaSizeName$vtype	*vtype;
	_jc_javax_print_attribute_standard_MediaSizeName$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_MediaSizeName$vtype _jc_javax_print_attribute_standard_MediaSizeName$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_MediaSizeName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_MediaSizeName$class_object;

#endif	/* _JC_javax_print_attribute_standard_MediaSizeName_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/MediaSizeName.h <==
// public class javax.print.attribute.standard.MediaSizeName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class ab3220e6946f401b javax_print_attribute_standard_Media
// @dep_class b153305f4aacd945 javax_print_attribute_standard_MediaSizeName

// header file dependencies
// @dep_header javax_print_attribute_standard_Media

#include "javax/print/attribute/standard/Media.h"

#ifndef _JC_javax_print_attribute_standard_MediaSizeName_H_
#define _JC_javax_print_attribute_standard_MediaSizeName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_standard_MediaSizeName$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_MediaSizeName$sub_refs	_jc_javax_print_attribute_standard_MediaSizeName$sub_refs;
typedef struct _jc_javax_print_attribute_standard_MediaSizeName$sub_nonrefs	_jc_javax_print_attribute_standard_MediaSizeName$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_MediaSizeName$refs	_jc_javax_print_attribute_standard_MediaSizeName$refs;
typedef struct _jc_javax_print_attribute_standard_MediaSizeName$nonrefs	_jc_javax_print_attribute_standard_MediaSizeName$nonrefs;
typedef struct _jc_javax_print_attribute_standard_MediaSizeName$object	_jc_javax_print_attribute_standard_MediaSizeName$object;

typedef struct _jc_javax_print_attribute_standard_MediaSizeName$fields_struct	_jc_javax_print_attribute_standard_MediaSizeName$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_MediaSizeName$vmethods	_jc_javax_print_attribute_standard_MediaSizeName$vmethods;
typedef const struct _jc_javax_print_attribute_standard_MediaSizeName$vtable	_jc_javax_print_attribute_standard_MediaSizeName$vtable;
typedef const struct _jc_javax_print_attribute_standard_MediaSizeName$vtype	_jc_javax_print_attribute_standard_MediaSizeName$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_MediaSizeName$fields_struct {
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*A;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*B;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*C;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*D;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*E;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*EXECUTIVE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*FOLIO;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*INVOICE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA0;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA1;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA10;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA2;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA3;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA4;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA5;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA6;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA7;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA8;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fA9;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB0;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB1;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB10;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB2;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB3;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB4;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB5;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB6;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB7;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB8;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fB9;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fC0;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fC1;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fC2;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fC3;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fC4;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fC5;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fC6;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ISO__5fDESIGNATED__5fLONG;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*ITALY__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JAPANESE__5fDOUBLE__5fPOSTCARD;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JAPANESE__5fPOSTCARD;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB0;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB1;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB10;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB2;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB3;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB4;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB5;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB6;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB7;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB8;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*JIS__5fB9;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*LEDGER;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*MONARCH__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f10X13__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f10X14__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f10X15__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f5X7;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f6X9__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f7X9__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f8X10;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f9X11__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5f9X12__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5fLEGAL;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5fLETTER;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5fNUMBER__5f10__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5fNUMBER__5f11__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5fNUMBER__5f12__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5fNUMBER__5f14__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*NA__5fNUMBER__5f9__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*PERSONAL__5fENVELOPE;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*QUARTO;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*TABLOID;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_MediaSizeName$fields_struct _jc_javax_print_attribute_standard_MediaSizeName$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_MediaSizeName$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSizeName$object *, jint) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_print_attribute_standard_MediaSizeName$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_MediaSizeName$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_standard_MediaSizeName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_Media$vmethods	javax_print_attribute_standard_Media;
	_jc_javax_print_attribute_standard_MediaSizeName$vmethods	javax_print_attribute_standard_MediaSizeName;
};

// Vtype
struct _jc_javax_print_attribute_standard_MediaSizeName$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_MediaSizeName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_MediaSizeName$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_MediaSizeName$refs {
    _jc_javax_print_attribute_standard_MediaSizeName$sub_refs	javax_print_attribute_standard_MediaSizeName;
    _jc_javax_print_attribute_standard_Media$sub_refs	javax_print_attribute_standard_Media;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_MediaSizeName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_MediaSizeName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_Media$sub_nonrefs	javax_print_attribute_standard_Media;
    _jc_javax_print_attribute_standard_MediaSizeName$sub_nonrefs	javax_print_attribute_standard_MediaSizeName;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_MediaSizeName$object {
	_jc_javax_print_attribute_standard_MediaSizeName$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_MediaSizeName$vtype	*vtype;
	_jc_javax_print_attribute_standard_MediaSizeName$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_MediaSizeName$vtype _jc_javax_print_attribute_standard_MediaSizeName$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_MediaSizeName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_MediaSizeName$class_object;

#endif	/* _JC_javax_print_attribute_standard_MediaSizeName_H_ */
